# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/project_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.datasphere.v1 import project_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datasphere/v1/project_service.proto',
  package='yandex.cloud.datasphere.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0yandex/cloud/datasphere/v1/project_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a(yandex/cloud/datasphere/v1/project.proto\"\x8e\x02\n\x14\x43reateProjectRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x39\n\x04name\x18\x02 \x01(\tB+\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x05 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\"+\n\x15\x43reateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\xc1\x02\n\x14UpdateProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x39\n\x04name\x18\x03 \x01(\tB+\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x06 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\"+\n\x15UpdateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"9\n\x14\x44\x65leteProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"+\n\x15\x44\x65leteProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"7\n\x12OpenProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\")\n\x13OpenProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"A\n\x13OpenProjectResponse\x12\x13\n\x0bproject_url\x18\x01 \x01(\t\x12\x15\n\rsession_token\x18\x02 \x01(\t\"6\n\x11GetProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"t\n\x13ListProjectsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.yandex.cloud.datasphere.v1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x15GetUnitBalanceRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"K\n\x16GetUnitBalanceResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"m\n\x15SetUnitBalanceRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x31\n\x0cunit_balance\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xdd\x01\n\x17ProjectExecutionRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x30\n\x0finput_variables\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1d\n\x15output_variable_names\x18\x05 \x03(\tB\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"~\n\x18ProjectExecutionMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"d\n\x18ProjectExecutionResponse\x12\x15\n\rcheckpoint_id\x18\x01 \x01(\t\x12\x31\n\x10output_variables\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x9c\x01\n\x12\x43\x65llOutputsRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x1e\n\x07\x63\x65ll_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x15\n\rcheckpoint_id\x18\x03 \x01(\t\x12,\n\x08start_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"&\n\x13\x43\x65llOutputsResponse\x12\x0f\n\x07outputs\x18\x01 \x03(\t\"\x90\x01\n\x18GetStateVariablesRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\"\n\x0bnotebook_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x16\n\x0evariable_names\x18\x03 \x03(\t\x12\x15\n\rcheckpoint_id\x18\x04 \x01(\t\"G\n\x19GetStateVariablesResponse\x12*\n\tvariables\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\\\n\x1aGetNotebookMetadataRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x1b\n\rnotebook_path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\xbd\x01\n\x1bGetNotebookMetadataResponse\x12\x13\n\x0bnotebook_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63ontent_length\x18\x04 \x01(\x03\x12\x10\n\x08\x63\x65ll_ids\x18\x05 \x03(\t2\xdb\x10\n\x0eProjectService\x12\xa5\x01\n\x06\x43reate\x12\x30.yandex.cloud.datasphere.v1.CreateProjectRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02\x1c\"\x17/datasphere/v1/projects:\x01*\xb2\xd2* \n\x15\x43reateProjectMetadata\x12\x07Project\x12\xb2\x01\n\x06Update\x12\x30.yandex.cloud.datasphere.v1.UpdateProjectRequest\x1a!.yandex.cloud.operation.Operation\"S\x82\xd3\xe4\x93\x02)2$/datasphere/v1/projects/{project_id}:\x01*\xb2\xd2* \n\x15UpdateProjectMetadata\x12\x07Project\x12\xbd\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.datasphere.v1.DeleteProjectRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02&*$/datasphere/v1/projects/{project_id}\xb2\xd2*.\n\x15\x44\x65leteProjectMetadata\x12\x15google.protobuf.Empty\x12\xba\x01\n\x04Open\x12..yandex.cloud.datasphere.v1.OpenProjectRequest\x1a!.yandex.cloud.operation.Operation\"_\x82\xd3\xe4\x93\x02+\")/datasphere/v1/projects/{project_id}:open\xb2\xd2**\n\x13OpenProjectMetadata\x12\x13OpenProjectResponse\x12\x87\x01\n\x03Get\x12-.yandex.cloud.datasphere.v1.GetProjectRequest\x1a#.yandex.cloud.datasphere.v1.Project\",\x82\xd3\xe4\x93\x02&\x12$/datasphere/v1/projects/{project_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.datasphere.v1.ListProjectsRequest\x1a\x30.yandex.cloud.datasphere.v1.ListProjectsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/datasphere/v1/projects\x12\xb1\x01\n\x0eGetUnitBalance\x12\x31.yandex.cloud.datasphere.v1.GetUnitBalanceRequest\x1a\x32.yandex.cloud.datasphere.v1.GetUnitBalanceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/datasphere/v1/projects/{project_id}:unitBalance\x12\x98\x01\n\x0eSetUnitBalance\x12\x31.yandex.cloud.datasphere.v1.SetUnitBalanceRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"0/datasphere/v1/projects/{project_id}:unitBalance:\x01*\x12\xd2\x01\n\x07\x45xecute\x12\x33.yandex.cloud.datasphere.v1.ProjectExecutionRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02\x31\",/datasphere/v1/projects/{project_id}:execute:\x01*\xb2\xd2*4\n\x18ProjectExecutionMetadata\x12\x18ProjectExecutionResponse\x12\xab\x01\n\x0eGetCellOutputs\x12..yandex.cloud.datasphere.v1.CellOutputsRequest\x1a/.yandex.cloud.datasphere.v1.CellOutputsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/datasphere/v1/projects/{project_id}:cellOutputs\x12\xbd\x01\n\x11GetStateVariables\x12\x34.yandex.cloud.datasphere.v1.GetStateVariablesRequest\x1a\x35.yandex.cloud.datasphere.v1.GetStateVariablesResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/datasphere/v1/projects/{project_id}:stateVariables\x12\xc5\x01\n\x13GetNotebookMetadata\x12\x36.yandex.cloud.datasphere.v1.GetNotebookMetadataRequest\x1a\x37.yandex.cloud.datasphere.v1.GetNotebookMetadataResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/datasphere/v1/projects/{project_id}:notebookMetadataBk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2.DESCRIPTOR,])




_CREATEPROJECTREQUEST = _descriptor.Descriptor(
  name='CreateProjectRequest',
  full_name='yandex.cloud.datasphere.v1.CreateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datasphere.v1.CreateProjectRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datasphere.v1.CreateProjectRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=63\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.datasphere.v1.CreateProjectRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='yandex.cloud.datasphere.v1.CreateProjectRequest.settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limits', full_name='yandex.cloud.datasphere.v1.CreateProjectRequest.limits', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=686,
)


_CREATEPROJECTMETADATA = _descriptor.Descriptor(
  name='CreateProjectMetadata',
  full_name='yandex.cloud.datasphere.v1.CreateProjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.CreateProjectMetadata.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=731,
)


_UPDATEPROJECTREQUEST = _descriptor.Descriptor(
  name='UpdateProjectRequest',
  full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=63\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest.settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limits', full_name='yandex.cloud.datasphere.v1.UpdateProjectRequest.limits', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=1055,
)


_UPDATEPROJECTMETADATA = _descriptor.Descriptor(
  name='UpdateProjectMetadata',
  full_name='yandex.cloud.datasphere.v1.UpdateProjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.UpdateProjectMetadata.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1100,
)


_DELETEPROJECTREQUEST = _descriptor.Descriptor(
  name='DeleteProjectRequest',
  full_name='yandex.cloud.datasphere.v1.DeleteProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.DeleteProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1102,
  serialized_end=1159,
)


_DELETEPROJECTMETADATA = _descriptor.Descriptor(
  name='DeleteProjectMetadata',
  full_name='yandex.cloud.datasphere.v1.DeleteProjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.DeleteProjectMetadata.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1204,
)


_OPENPROJECTREQUEST = _descriptor.Descriptor(
  name='OpenProjectRequest',
  full_name='yandex.cloud.datasphere.v1.OpenProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.OpenProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1206,
  serialized_end=1261,
)


_OPENPROJECTMETADATA = _descriptor.Descriptor(
  name='OpenProjectMetadata',
  full_name='yandex.cloud.datasphere.v1.OpenProjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.OpenProjectMetadata.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1263,
  serialized_end=1304,
)


_OPENPROJECTRESPONSE = _descriptor.Descriptor(
  name='OpenProjectResponse',
  full_name='yandex.cloud.datasphere.v1.OpenProjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_url', full_name='yandex.cloud.datasphere.v1.OpenProjectResponse.project_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_token', full_name='yandex.cloud.datasphere.v1.OpenProjectResponse.session_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1306,
  serialized_end=1371,
)


_GETPROJECTREQUEST = _descriptor.Descriptor(
  name='GetProjectRequest',
  full_name='yandex.cloud.datasphere.v1.GetProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.GetProjectRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1373,
  serialized_end=1427,
)


_LISTPROJECTSREQUEST = _descriptor.Descriptor(
  name='ListProjectsRequest',
  full_name='yandex.cloud.datasphere.v1.ListProjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datasphere.v1.ListProjectsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.datasphere.v1.ListProjectsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.datasphere.v1.ListProjectsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1429,
  serialized_end=1545,
)


_LISTPROJECTSRESPONSE = _descriptor.Descriptor(
  name='ListProjectsResponse',
  full_name='yandex.cloud.datasphere.v1.ListProjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='projects', full_name='yandex.cloud.datasphere.v1.ListProjectsResponse.projects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.datasphere.v1.ListProjectsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1547,
  serialized_end=1649,
)


_GETUNITBALANCEREQUEST = _descriptor.Descriptor(
  name='GetUnitBalanceRequest',
  full_name='yandex.cloud.datasphere.v1.GetUnitBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.GetUnitBalanceRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1651,
  serialized_end=1709,
)


_GETUNITBALANCERESPONSE = _descriptor.Descriptor(
  name='GetUnitBalanceResponse',
  full_name='yandex.cloud.datasphere.v1.GetUnitBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_balance', full_name='yandex.cloud.datasphere.v1.GetUnitBalanceResponse.unit_balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1786,
)


_SETUNITBALANCEREQUEST = _descriptor.Descriptor(
  name='SetUnitBalanceRequest',
  full_name='yandex.cloud.datasphere.v1.SetUnitBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.SetUnitBalanceRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_balance', full_name='yandex.cloud.datasphere.v1.SetUnitBalanceRequest.unit_balance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1788,
  serialized_end=1897,
)


_PROJECTEXECUTIONREQUEST = _descriptor.Descriptor(
  name='ProjectExecutionRequest',
  full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebook_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest.notebook_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest.cell_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_variables', full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest.input_variables', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_variable_names', full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest.output_variable_names', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='yandex.cloud.datasphere.v1.ProjectExecutionRequest.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1900,
  serialized_end=2121,
)


_PROJECTEXECUTIONMETADATA = _descriptor.Descriptor(
  name='ProjectExecutionMetadata',
  full_name='yandex.cloud.datasphere.v1.ProjectExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionMetadata.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebook_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionMetadata.notebook_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionMetadata.cell_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='yandex.cloud.datasphere.v1.ProjectExecutionMetadata.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2123,
  serialized_end=2249,
)


_PROJECTEXECUTIONRESPONSE = _descriptor.Descriptor(
  name='ProjectExecutionResponse',
  full_name='yandex.cloud.datasphere.v1.ProjectExecutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checkpoint_id', full_name='yandex.cloud.datasphere.v1.ProjectExecutionResponse.checkpoint_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_variables', full_name='yandex.cloud.datasphere.v1.ProjectExecutionResponse.output_variables', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2351,
)


_CELLOUTPUTSREQUEST = _descriptor.Descriptor(
  name='CellOutputsRequest',
  full_name='yandex.cloud.datasphere.v1.CellOutputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.CellOutputsRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='yandex.cloud.datasphere.v1.CellOutputsRequest.cell_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_id', full_name='yandex.cloud.datasphere.v1.CellOutputsRequest.checkpoint_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_at', full_name='yandex.cloud.datasphere.v1.CellOutputsRequest.start_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2354,
  serialized_end=2510,
)


_CELLOUTPUTSRESPONSE = _descriptor.Descriptor(
  name='CellOutputsResponse',
  full_name='yandex.cloud.datasphere.v1.CellOutputsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='yandex.cloud.datasphere.v1.CellOutputsResponse.outputs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2512,
  serialized_end=2550,
)


_GETSTATEVARIABLESREQUEST = _descriptor.Descriptor(
  name='GetStateVariablesRequest',
  full_name='yandex.cloud.datasphere.v1.GetStateVariablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.GetStateVariablesRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebook_id', full_name='yandex.cloud.datasphere.v1.GetStateVariablesRequest.notebook_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable_names', full_name='yandex.cloud.datasphere.v1.GetStateVariablesRequest.variable_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_id', full_name='yandex.cloud.datasphere.v1.GetStateVariablesRequest.checkpoint_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2553,
  serialized_end=2697,
)


_GETSTATEVARIABLESRESPONSE = _descriptor.Descriptor(
  name='GetStateVariablesResponse',
  full_name='yandex.cloud.datasphere.v1.GetStateVariablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables', full_name='yandex.cloud.datasphere.v1.GetStateVariablesResponse.variables', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2699,
  serialized_end=2770,
)


_GETNOTEBOOKMETADATAREQUEST = _descriptor.Descriptor(
  name='GetNotebookMetadataRequest',
  full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataRequest.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebook_path', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataRequest.notebook_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=2864,
)


_GETNOTEBOOKMETADATARESPONSE = _descriptor.Descriptor(
  name='GetNotebookMetadataResponse',
  full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notebook_id', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataResponse.notebook_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataResponse.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_at', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataResponse.modified_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_length', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataResponse.content_length', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_ids', full_name='yandex.cloud.datasphere.v1.GetNotebookMetadataResponse.cell_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2867,
  serialized_end=3056,
)

_CREATEPROJECTREQUEST.fields_by_name['settings'].message_type = yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2._PROJECT_SETTINGS
_CREATEPROJECTREQUEST.fields_by_name['limits'].message_type = yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2._PROJECT_LIMITS
_UPDATEPROJECTREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEPROJECTREQUEST.fields_by_name['settings'].message_type = yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2._PROJECT_SETTINGS
_UPDATEPROJECTREQUEST.fields_by_name['limits'].message_type = yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2._PROJECT_LIMITS
_LISTPROJECTSRESPONSE.fields_by_name['projects'].message_type = yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2._PROJECT
_GETUNITBALANCERESPONSE.fields_by_name['unit_balance'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SETUNITBALANCEREQUEST.fields_by_name['unit_balance'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PROJECTEXECUTIONREQUEST.fields_by_name['input_variables'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PROJECTEXECUTIONREQUEST.oneofs_by_name['target'].fields.append(
  _PROJECTEXECUTIONREQUEST.fields_by_name['notebook_id'])
_PROJECTEXECUTIONREQUEST.fields_by_name['notebook_id'].containing_oneof = _PROJECTEXECUTIONREQUEST.oneofs_by_name['target']
_PROJECTEXECUTIONREQUEST.oneofs_by_name['target'].fields.append(
  _PROJECTEXECUTIONREQUEST.fields_by_name['cell_id'])
_PROJECTEXECUTIONREQUEST.fields_by_name['cell_id'].containing_oneof = _PROJECTEXECUTIONREQUEST.oneofs_by_name['target']
_PROJECTEXECUTIONMETADATA.oneofs_by_name['target'].fields.append(
  _PROJECTEXECUTIONMETADATA.fields_by_name['notebook_id'])
_PROJECTEXECUTIONMETADATA.fields_by_name['notebook_id'].containing_oneof = _PROJECTEXECUTIONMETADATA.oneofs_by_name['target']
_PROJECTEXECUTIONMETADATA.oneofs_by_name['target'].fields.append(
  _PROJECTEXECUTIONMETADATA.fields_by_name['cell_id'])
_PROJECTEXECUTIONMETADATA.fields_by_name['cell_id'].containing_oneof = _PROJECTEXECUTIONMETADATA.oneofs_by_name['target']
_PROJECTEXECUTIONRESPONSE.fields_by_name['output_variables'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CELLOUTPUTSREQUEST.fields_by_name['start_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETSTATEVARIABLESRESPONSE.fields_by_name['variables'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GETNOTEBOOKMETADATARESPONSE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETNOTEBOOKMETADATARESPONSE.fields_by_name['modified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['CreateProjectRequest'] = _CREATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['CreateProjectMetadata'] = _CREATEPROJECTMETADATA
DESCRIPTOR.message_types_by_name['UpdateProjectRequest'] = _UPDATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['UpdateProjectMetadata'] = _UPDATEPROJECTMETADATA
DESCRIPTOR.message_types_by_name['DeleteProjectRequest'] = _DELETEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['DeleteProjectMetadata'] = _DELETEPROJECTMETADATA
DESCRIPTOR.message_types_by_name['OpenProjectRequest'] = _OPENPROJECTREQUEST
DESCRIPTOR.message_types_by_name['OpenProjectMetadata'] = _OPENPROJECTMETADATA
DESCRIPTOR.message_types_by_name['OpenProjectResponse'] = _OPENPROJECTRESPONSE
DESCRIPTOR.message_types_by_name['GetProjectRequest'] = _GETPROJECTREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsRequest'] = _LISTPROJECTSREQUEST
DESCRIPTOR.message_types_by_name['ListProjectsResponse'] = _LISTPROJECTSRESPONSE
DESCRIPTOR.message_types_by_name['GetUnitBalanceRequest'] = _GETUNITBALANCEREQUEST
DESCRIPTOR.message_types_by_name['GetUnitBalanceResponse'] = _GETUNITBALANCERESPONSE
DESCRIPTOR.message_types_by_name['SetUnitBalanceRequest'] = _SETUNITBALANCEREQUEST
DESCRIPTOR.message_types_by_name['ProjectExecutionRequest'] = _PROJECTEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name['ProjectExecutionMetadata'] = _PROJECTEXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['ProjectExecutionResponse'] = _PROJECTEXECUTIONRESPONSE
DESCRIPTOR.message_types_by_name['CellOutputsRequest'] = _CELLOUTPUTSREQUEST
DESCRIPTOR.message_types_by_name['CellOutputsResponse'] = _CELLOUTPUTSRESPONSE
DESCRIPTOR.message_types_by_name['GetStateVariablesRequest'] = _GETSTATEVARIABLESREQUEST
DESCRIPTOR.message_types_by_name['GetStateVariablesResponse'] = _GETSTATEVARIABLESRESPONSE
DESCRIPTOR.message_types_by_name['GetNotebookMetadataRequest'] = _GETNOTEBOOKMETADATAREQUEST
DESCRIPTOR.message_types_by_name['GetNotebookMetadataResponse'] = _GETNOTEBOOKMETADATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

CreateProjectMetadata = _reflection.GeneratedProtocolMessageType('CreateProjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTMETADATA,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.CreateProjectMetadata)
  })
_sym_db.RegisterMessage(CreateProjectMetadata)

UpdateProjectRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.UpdateProjectRequest)
  })
_sym_db.RegisterMessage(UpdateProjectRequest)

UpdateProjectMetadata = _reflection.GeneratedProtocolMessageType('UpdateProjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTMETADATA,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.UpdateProjectMetadata)
  })
_sym_db.RegisterMessage(UpdateProjectMetadata)

DeleteProjectRequest = _reflection.GeneratedProtocolMessageType('DeleteProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.DeleteProjectRequest)
  })
_sym_db.RegisterMessage(DeleteProjectRequest)

DeleteProjectMetadata = _reflection.GeneratedProtocolMessageType('DeleteProjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROJECTMETADATA,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.DeleteProjectMetadata)
  })
_sym_db.RegisterMessage(DeleteProjectMetadata)

OpenProjectRequest = _reflection.GeneratedProtocolMessageType('OpenProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENPROJECTREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.OpenProjectRequest)
  })
_sym_db.RegisterMessage(OpenProjectRequest)

OpenProjectMetadata = _reflection.GeneratedProtocolMessageType('OpenProjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _OPENPROJECTMETADATA,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.OpenProjectMetadata)
  })
_sym_db.RegisterMessage(OpenProjectMetadata)

OpenProjectResponse = _reflection.GeneratedProtocolMessageType('OpenProjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPENPROJECTRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.OpenProjectResponse)
  })
_sym_db.RegisterMessage(OpenProjectResponse)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)

GetUnitBalanceRequest = _reflection.GeneratedProtocolMessageType('GetUnitBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNITBALANCEREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetUnitBalanceRequest)
  })
_sym_db.RegisterMessage(GetUnitBalanceRequest)

GetUnitBalanceResponse = _reflection.GeneratedProtocolMessageType('GetUnitBalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUNITBALANCERESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetUnitBalanceResponse)
  })
_sym_db.RegisterMessage(GetUnitBalanceResponse)

SetUnitBalanceRequest = _reflection.GeneratedProtocolMessageType('SetUnitBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETUNITBALANCEREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.SetUnitBalanceRequest)
  })
_sym_db.RegisterMessage(SetUnitBalanceRequest)

ProjectExecutionRequest = _reflection.GeneratedProtocolMessageType('ProjectExecutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTEXECUTIONREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.ProjectExecutionRequest)
  })
_sym_db.RegisterMessage(ProjectExecutionRequest)

ProjectExecutionMetadata = _reflection.GeneratedProtocolMessageType('ProjectExecutionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTEXECUTIONMETADATA,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.ProjectExecutionMetadata)
  })
_sym_db.RegisterMessage(ProjectExecutionMetadata)

ProjectExecutionResponse = _reflection.GeneratedProtocolMessageType('ProjectExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTEXECUTIONRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.ProjectExecutionResponse)
  })
_sym_db.RegisterMessage(ProjectExecutionResponse)

CellOutputsRequest = _reflection.GeneratedProtocolMessageType('CellOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CELLOUTPUTSREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.CellOutputsRequest)
  })
_sym_db.RegisterMessage(CellOutputsRequest)

CellOutputsResponse = _reflection.GeneratedProtocolMessageType('CellOutputsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CELLOUTPUTSRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.CellOutputsResponse)
  })
_sym_db.RegisterMessage(CellOutputsResponse)

GetStateVariablesRequest = _reflection.GeneratedProtocolMessageType('GetStateVariablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEVARIABLESREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetStateVariablesRequest)
  })
_sym_db.RegisterMessage(GetStateVariablesRequest)

GetStateVariablesResponse = _reflection.GeneratedProtocolMessageType('GetStateVariablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEVARIABLESRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetStateVariablesResponse)
  })
_sym_db.RegisterMessage(GetStateVariablesResponse)

GetNotebookMetadataRequest = _reflection.GeneratedProtocolMessageType('GetNotebookMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKMETADATAREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetNotebookMetadataRequest)
  })
_sym_db.RegisterMessage(GetNotebookMetadataRequest)

GetNotebookMetadataResponse = _reflection.GeneratedProtocolMessageType('GetNotebookMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKMETADATARESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.project_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.GetNotebookMetadataResponse)
  })
_sym_db.RegisterMessage(GetNotebookMetadataResponse)


DESCRIPTOR._options = None
_CREATEPROJECTREQUEST.fields_by_name['folder_id']._options = None
_CREATEPROJECTREQUEST.fields_by_name['name']._options = None
_CREATEPROJECTREQUEST.fields_by_name['description']._options = None
_UPDATEPROJECTREQUEST.fields_by_name['project_id']._options = None
_UPDATEPROJECTREQUEST.fields_by_name['name']._options = None
_UPDATEPROJECTREQUEST.fields_by_name['description']._options = None
_DELETEPROJECTREQUEST.fields_by_name['project_id']._options = None
_OPENPROJECTREQUEST.fields_by_name['project_id']._options = None
_GETPROJECTREQUEST.fields_by_name['project_id']._options = None
_LISTPROJECTSREQUEST.fields_by_name['folder_id']._options = None
_LISTPROJECTSREQUEST.fields_by_name['page_size']._options = None
_LISTPROJECTSREQUEST.fields_by_name['page_token']._options = None
_GETUNITBALANCEREQUEST.fields_by_name['project_id']._options = None
_SETUNITBALANCEREQUEST.fields_by_name['project_id']._options = None
_PROJECTEXECUTIONREQUEST.oneofs_by_name['target']._options = None
_PROJECTEXECUTIONREQUEST.fields_by_name['project_id']._options = None
_PROJECTEXECUTIONREQUEST.fields_by_name['notebook_id']._options = None
_PROJECTEXECUTIONREQUEST.fields_by_name['cell_id']._options = None
_PROJECTEXECUTIONMETADATA.oneofs_by_name['target']._options = None
_PROJECTEXECUTIONMETADATA.fields_by_name['notebook_id']._options = None
_PROJECTEXECUTIONMETADATA.fields_by_name['cell_id']._options = None
_CELLOUTPUTSREQUEST.fields_by_name['project_id']._options = None
_CELLOUTPUTSREQUEST.fields_by_name['cell_id']._options = None
_GETSTATEVARIABLESREQUEST.fields_by_name['project_id']._options = None
_GETSTATEVARIABLESREQUEST.fields_by_name['notebook_id']._options = None
_GETNOTEBOOKMETADATAREQUEST.fields_by_name['project_id']._options = None
_GETNOTEBOOKMETADATAREQUEST.fields_by_name['notebook_path']._options = None

_PROJECTSERVICE = _descriptor.ServiceDescriptor(
  name='ProjectService',
  full_name='yandex.cloud.datasphere.v1.ProjectService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3059,
  serialized_end=5198,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.datasphere.v1.ProjectService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEPROJECTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\034\"\027/datasphere/v1/projects:\001*\262\322* \n\025CreateProjectMetadata\022\007Project',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.datasphere.v1.ProjectService.Update',
    index=1,
    containing_service=None,
    input_type=_UPDATEPROJECTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002)2$/datasphere/v1/projects/{project_id}:\001*\262\322* \n\025UpdateProjectMetadata\022\007Project',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.datasphere.v1.ProjectService.Delete',
    index=2,
    containing_service=None,
    input_type=_DELETEPROJECTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&*$/datasphere/v1/projects/{project_id}\262\322*.\n\025DeleteProjectMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Open',
    full_name='yandex.cloud.datasphere.v1.ProjectService.Open',
    index=3,
    containing_service=None,
    input_type=_OPENPROJECTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+\")/datasphere/v1/projects/{project_id}:open\262\322**\n\023OpenProjectMetadata\022\023OpenProjectResponse',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.datasphere.v1.ProjectService.Get',
    index=4,
    containing_service=None,
    input_type=_GETPROJECTREQUEST,
    output_type=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2._PROJECT,
    serialized_options=b'\202\323\344\223\002&\022$/datasphere/v1/projects/{project_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.datasphere.v1.ProjectService.List',
    index=5,
    containing_service=None,
    input_type=_LISTPROJECTSREQUEST,
    output_type=_LISTPROJECTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/datasphere/v1/projects',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUnitBalance',
    full_name='yandex.cloud.datasphere.v1.ProjectService.GetUnitBalance',
    index=6,
    containing_service=None,
    input_type=_GETUNITBALANCEREQUEST,
    output_type=_GETUNITBALANCERESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/datasphere/v1/projects/{project_id}:unitBalance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetUnitBalance',
    full_name='yandex.cloud.datasphere.v1.ProjectService.SetUnitBalance',
    index=7,
    containing_service=None,
    input_type=_SETUNITBALANCEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\0025\"0/datasphere/v1/projects/{project_id}:unitBalance:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='yandex.cloud.datasphere.v1.ProjectService.Execute',
    index=8,
    containing_service=None,
    input_type=_PROJECTEXECUTIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021\",/datasphere/v1/projects/{project_id}:execute:\001*\262\322*4\n\030ProjectExecutionMetadata\022\030ProjectExecutionResponse',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCellOutputs',
    full_name='yandex.cloud.datasphere.v1.ProjectService.GetCellOutputs',
    index=9,
    containing_service=None,
    input_type=_CELLOUTPUTSREQUEST,
    output_type=_CELLOUTPUTSRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/datasphere/v1/projects/{project_id}:cellOutputs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStateVariables',
    full_name='yandex.cloud.datasphere.v1.ProjectService.GetStateVariables',
    index=10,
    containing_service=None,
    input_type=_GETSTATEVARIABLESREQUEST,
    output_type=_GETSTATEVARIABLESRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/datasphere/v1/projects/{project_id}:stateVariables',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotebookMetadata',
    full_name='yandex.cloud.datasphere.v1.ProjectService.GetNotebookMetadata',
    index=11,
    containing_service=None,
    input_type=_GETNOTEBOOKMETADATAREQUEST,
    output_type=_GETNOTEBOOKMETADATARESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/datasphere/v1/projects/{project_id}:notebookMetadata',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROJECTSERVICE)

DESCRIPTOR.services_by_name['ProjectService'] = _PROJECTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/address_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.vpc.v1 import address_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/vpc/v1/address_service.proto',
  package='yandex.cloud.vpc.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/vpc/v1/address_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a!yandex/cloud/vpc/v1/address.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"F\n\x18GetAddressByValueRequest\x12\x1f\n\x15\x65xternal_ipv4_address\x18\x01 \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ress\"\x85\x01\n\x14ListAddressesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"a\n\x15ListAddressesResponse\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Address\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc1\x03\n\x14\x43reateAddressRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12R\n\x1a\x65xternal_ipv4_address_spec\x18\x05 \x01(\x0b\x32,.yandex.cloud.vpc.v1.ExternalIpv4AddressSpecH\x00\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0c\x61\x64\x64ress_spec\"{\n\x17\x45xternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07zone_id\x18\x02 \x01(\t\x12>\n\x0crequirements\x18\x03 \x01(\x0b\x32(.yandex.cloud.vpc.v1.AddressRequirements\"+\n\x15\x43reateAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"\xa1\x03\n\x14UpdateAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x10\n\x08reserved\x18\x06 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"~\n\x1cListAddressOperationsRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListAddressOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t2\xc7\t\n\x0e\x41\x64\x64ressService\x12s\n\x03Get\x12&.yandex.cloud.vpc.v1.GetAddressRequest\x1a\x1c.yandex.cloud.vpc.v1.Address\"&\x82\xd3\xe4\x93\x02 \x12\x1e/vpc/v1/addresses/{address_id}\x12|\n\nGetByValue\x12-.yandex.cloud.vpc.v1.GetAddressByValueRequest\x1a\x1c.yandex.cloud.vpc.v1.Address\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/vpc/v1/addresses:byValue\x12x\n\x04List\x12).yandex.cloud.vpc.v1.ListAddressesRequest\x1a*.yandex.cloud.vpc.v1.ListAddressesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/vpc/v1/addresses\x12\x98\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateAddressRequest\x1a!.yandex.cloud.operation.Operation\"@\x82\xd3\xe4\x93\x02\x16\"\x11/vpc/v1/addresses:\x01*\xb2\xd2* \n\x15\x43reateAddressMetadata\x12\x07\x41\x64\x64ress\x12\xa5\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateAddressRequest\x1a!.yandex.cloud.operation.Operation\"M\x82\xd3\xe4\x93\x02#2\x1e/vpc/v1/addresses/{address_id}:\x01*\xb2\xd2* \n\x15UpdateAddressMetadata\x12\x07\x41\x64\x64ress\x12\xb0\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteAddressRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02 *\x1e/vpc/v1/addresses/{address_id}\xb2\xd2*.\n\x15\x44\x65leteAddressMetadata\x12\x15google.protobuf.Empty\x12\xaa\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListAddressOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListAddressOperationsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/vpc/v1/addresses/{address_id}/operations\x12\xa4\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveAddressRequest\x1a!.yandex.cloud.operation.Operation\"P\x82\xd3\xe4\x93\x02(\"#/vpc/v1/addresses/{address_id}:move:\x01*\xb2\xd2*\x1e\n\x13MoveAddressMetadata\x12\x07\x41\x64\x64ressBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETADDRESSREQUEST = _descriptor.Descriptor(
  name='GetAddressRequest',
  full_name='yandex.cloud.vpc.v1.GetAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.GetAddressRequest.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=323,
)


_GETADDRESSBYVALUEREQUEST = _descriptor.Descriptor(
  name='GetAddressByValueRequest',
  full_name='yandex.cloud.vpc.v1.GetAddressByValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_ipv4_address', full_name='yandex.cloud.vpc.v1.GetAddressByValueRequest.external_ipv4_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='yandex.cloud.vpc.v1.GetAddressByValueRequest.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=325,
  serialized_end=395,
)


_LISTADDRESSESREQUEST = _descriptor.Descriptor(
  name='ListAddressesRequest',
  full_name='yandex.cloud.vpc.v1.ListAddressesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.ListAddressesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListAddressesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListAddressesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.vpc.v1.ListAddressesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=531,
)


_LISTADDRESSESRESPONSE = _descriptor.Descriptor(
  name='ListAddressesResponse',
  full_name='yandex.cloud.vpc.v1.ListAddressesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='yandex.cloud.vpc.v1.ListAddressesResponse.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListAddressesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=630,
)


_CREATEADDRESSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1066,
)

_CREATEADDRESSREQUEST = _descriptor.Descriptor(
  name='CreateAddressRequest',
  full_name='yandex.cloud.vpc.v1.CreateAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_ipv4_address_spec', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.external_ipv4_address_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.deletion_protection', index=5,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEADDRESSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address_spec', full_name='yandex.cloud.vpc.v1.CreateAddressRequest.address_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=633,
  serialized_end=1082,
)


_EXTERNALIPV4ADDRESSSPEC = _descriptor.Descriptor(
  name='ExternalIpv4AddressSpec',
  full_name='yandex.cloud.vpc.v1.ExternalIpv4AddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.vpc.v1.ExternalIpv4AddressSpec.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.vpc.v1.ExternalIpv4AddressSpec.zone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirements', full_name='yandex.cloud.vpc.v1.ExternalIpv4AddressSpec.requirements', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1207,
)


_CREATEADDRESSMETADATA = _descriptor.Descriptor(
  name='CreateAddressMetadata',
  full_name='yandex.cloud.vpc.v1.CreateAddressMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.CreateAddressMetadata.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1209,
  serialized_end=1252,
)


_UPDATEADDRESSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1066,
)

_UPDATEADDRESSREQUEST = _descriptor.Descriptor(
  name='UpdateAddressRequest',
  full_name='yandex.cloud.vpc.v1.UpdateAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.reserved', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.vpc.v1.UpdateAddressRequest.deletion_protection', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEADDRESSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1672,
)


_UPDATEADDRESSMETADATA = _descriptor.Descriptor(
  name='UpdateAddressMetadata',
  full_name='yandex.cloud.vpc.v1.UpdateAddressMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.UpdateAddressMetadata.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1674,
  serialized_end=1717,
)


_DELETEADDRESSREQUEST = _descriptor.Descriptor(
  name='DeleteAddressRequest',
  full_name='yandex.cloud.vpc.v1.DeleteAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.DeleteAddressRequest.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1775,
)


_DELETEADDRESSMETADATA = _descriptor.Descriptor(
  name='DeleteAddressMetadata',
  full_name='yandex.cloud.vpc.v1.DeleteAddressMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.DeleteAddressMetadata.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1777,
  serialized_end=1820,
)


_LISTADDRESSOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListAddressOperationsRequest',
  full_name='yandex.cloud.vpc.v1.ListAddressOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.ListAddressOperationsRequest.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.vpc.v1.ListAddressOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.vpc.v1.ListAddressOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1948,
)


_LISTADDRESSOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListAddressOperationsResponse',
  full_name='yandex.cloud.vpc.v1.ListAddressOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.vpc.v1.ListAddressOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.vpc.v1.ListAddressOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1950,
  serialized_end=2061,
)


_MOVEADDRESSREQUEST = _descriptor.Descriptor(
  name='MoveAddressRequest',
  full_name='yandex.cloud.vpc.v1.MoveAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.MoveAddressRequest.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.vpc.v1.MoveAddressRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2063,
  serialized_end=2162,
)


_MOVEADDRESSMETADATA = _descriptor.Descriptor(
  name='MoveAddressMetadata',
  full_name='yandex.cloud.vpc.v1.MoveAddressMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_id', full_name='yandex.cloud.vpc.v1.MoveAddressMetadata.address_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2164,
  serialized_end=2205,
)

_GETADDRESSBYVALUEREQUEST.oneofs_by_name['address'].fields.append(
  _GETADDRESSBYVALUEREQUEST.fields_by_name['external_ipv4_address'])
_GETADDRESSBYVALUEREQUEST.fields_by_name['external_ipv4_address'].containing_oneof = _GETADDRESSBYVALUEREQUEST.oneofs_by_name['address']
_LISTADDRESSESRESPONSE.fields_by_name['addresses'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2._ADDRESS
_CREATEADDRESSREQUEST_LABELSENTRY.containing_type = _CREATEADDRESSREQUEST
_CREATEADDRESSREQUEST.fields_by_name['labels'].message_type = _CREATEADDRESSREQUEST_LABELSENTRY
_CREATEADDRESSREQUEST.fields_by_name['external_ipv4_address_spec'].message_type = _EXTERNALIPV4ADDRESSSPEC
_CREATEADDRESSREQUEST.oneofs_by_name['address_spec'].fields.append(
  _CREATEADDRESSREQUEST.fields_by_name['external_ipv4_address_spec'])
_CREATEADDRESSREQUEST.fields_by_name['external_ipv4_address_spec'].containing_oneof = _CREATEADDRESSREQUEST.oneofs_by_name['address_spec']
_EXTERNALIPV4ADDRESSSPEC.fields_by_name['requirements'].message_type = yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2._ADDRESSREQUIREMENTS
_UPDATEADDRESSREQUEST_LABELSENTRY.containing_type = _UPDATEADDRESSREQUEST
_UPDATEADDRESSREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEADDRESSREQUEST.fields_by_name['labels'].message_type = _UPDATEADDRESSREQUEST_LABELSENTRY
_LISTADDRESSOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetAddressRequest'] = _GETADDRESSREQUEST
DESCRIPTOR.message_types_by_name['GetAddressByValueRequest'] = _GETADDRESSBYVALUEREQUEST
DESCRIPTOR.message_types_by_name['ListAddressesRequest'] = _LISTADDRESSESREQUEST
DESCRIPTOR.message_types_by_name['ListAddressesResponse'] = _LISTADDRESSESRESPONSE
DESCRIPTOR.message_types_by_name['CreateAddressRequest'] = _CREATEADDRESSREQUEST
DESCRIPTOR.message_types_by_name['ExternalIpv4AddressSpec'] = _EXTERNALIPV4ADDRESSSPEC
DESCRIPTOR.message_types_by_name['CreateAddressMetadata'] = _CREATEADDRESSMETADATA
DESCRIPTOR.message_types_by_name['UpdateAddressRequest'] = _UPDATEADDRESSREQUEST
DESCRIPTOR.message_types_by_name['UpdateAddressMetadata'] = _UPDATEADDRESSMETADATA
DESCRIPTOR.message_types_by_name['DeleteAddressRequest'] = _DELETEADDRESSREQUEST
DESCRIPTOR.message_types_by_name['DeleteAddressMetadata'] = _DELETEADDRESSMETADATA
DESCRIPTOR.message_types_by_name['ListAddressOperationsRequest'] = _LISTADDRESSOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListAddressOperationsResponse'] = _LISTADDRESSOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['MoveAddressRequest'] = _MOVEADDRESSREQUEST
DESCRIPTOR.message_types_by_name['MoveAddressMetadata'] = _MOVEADDRESSMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAddressRequest = _reflection.GeneratedProtocolMessageType('GetAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETADDRESSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.GetAddressRequest)
  })
_sym_db.RegisterMessage(GetAddressRequest)

GetAddressByValueRequest = _reflection.GeneratedProtocolMessageType('GetAddressByValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETADDRESSBYVALUEREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.GetAddressByValueRequest)
  })
_sym_db.RegisterMessage(GetAddressByValueRequest)

ListAddressesRequest = _reflection.GeneratedProtocolMessageType('ListAddressesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTADDRESSESREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListAddressesRequest)
  })
_sym_db.RegisterMessage(ListAddressesRequest)

ListAddressesResponse = _reflection.GeneratedProtocolMessageType('ListAddressesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTADDRESSESRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListAddressesResponse)
  })
_sym_db.RegisterMessage(ListAddressesResponse)

CreateAddressRequest = _reflection.GeneratedProtocolMessageType('CreateAddressRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEADDRESSREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEADDRESSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateAddressRequest)
  })
_sym_db.RegisterMessage(CreateAddressRequest)
_sym_db.RegisterMessage(CreateAddressRequest.LabelsEntry)

ExternalIpv4AddressSpec = _reflection.GeneratedProtocolMessageType('ExternalIpv4AddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALIPV4ADDRESSSPEC,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ExternalIpv4AddressSpec)
  })
_sym_db.RegisterMessage(ExternalIpv4AddressSpec)

CreateAddressMetadata = _reflection.GeneratedProtocolMessageType('CreateAddressMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEADDRESSMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.CreateAddressMetadata)
  })
_sym_db.RegisterMessage(CreateAddressMetadata)

UpdateAddressRequest = _reflection.GeneratedProtocolMessageType('UpdateAddressRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEADDRESSREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEADDRESSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateAddressRequest)
  })
_sym_db.RegisterMessage(UpdateAddressRequest)
_sym_db.RegisterMessage(UpdateAddressRequest.LabelsEntry)

UpdateAddressMetadata = _reflection.GeneratedProtocolMessageType('UpdateAddressMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEADDRESSMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.UpdateAddressMetadata)
  })
_sym_db.RegisterMessage(UpdateAddressMetadata)

DeleteAddressRequest = _reflection.GeneratedProtocolMessageType('DeleteAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEADDRESSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteAddressRequest)
  })
_sym_db.RegisterMessage(DeleteAddressRequest)

DeleteAddressMetadata = _reflection.GeneratedProtocolMessageType('DeleteAddressMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEADDRESSMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.DeleteAddressMetadata)
  })
_sym_db.RegisterMessage(DeleteAddressMetadata)

ListAddressOperationsRequest = _reflection.GeneratedProtocolMessageType('ListAddressOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTADDRESSOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListAddressOperationsRequest)
  })
_sym_db.RegisterMessage(ListAddressOperationsRequest)

ListAddressOperationsResponse = _reflection.GeneratedProtocolMessageType('ListAddressOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTADDRESSOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.ListAddressOperationsResponse)
  })
_sym_db.RegisterMessage(ListAddressOperationsResponse)

MoveAddressRequest = _reflection.GeneratedProtocolMessageType('MoveAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEADDRESSREQUEST,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveAddressRequest)
  })
_sym_db.RegisterMessage(MoveAddressRequest)

MoveAddressMetadata = _reflection.GeneratedProtocolMessageType('MoveAddressMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVEADDRESSMETADATA,
  '__module__' : 'yandex.cloud.vpc.v1.address_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.vpc.v1.MoveAddressMetadata)
  })
_sym_db.RegisterMessage(MoveAddressMetadata)


DESCRIPTOR._options = None
_GETADDRESSREQUEST.fields_by_name['address_id']._options = None
_LISTADDRESSESREQUEST.fields_by_name['folder_id']._options = None
_LISTADDRESSESREQUEST.fields_by_name['page_size']._options = None
_LISTADDRESSESREQUEST.fields_by_name['page_token']._options = None
_CREATEADDRESSREQUEST_LABELSENTRY._options = None
_CREATEADDRESSREQUEST.fields_by_name['folder_id']._options = None
_CREATEADDRESSREQUEST.fields_by_name['name']._options = None
_CREATEADDRESSREQUEST.fields_by_name['description']._options = None
_CREATEADDRESSREQUEST.fields_by_name['labels']._options = None
_UPDATEADDRESSREQUEST_LABELSENTRY._options = None
_UPDATEADDRESSREQUEST.fields_by_name['address_id']._options = None
_UPDATEADDRESSREQUEST.fields_by_name['name']._options = None
_UPDATEADDRESSREQUEST.fields_by_name['description']._options = None
_UPDATEADDRESSREQUEST.fields_by_name['labels']._options = None
_DELETEADDRESSREQUEST.fields_by_name['address_id']._options = None
_LISTADDRESSOPERATIONSREQUEST.fields_by_name['address_id']._options = None
_LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_MOVEADDRESSREQUEST.fields_by_name['address_id']._options = None
_MOVEADDRESSREQUEST.fields_by_name['destination_folder_id']._options = None

_ADDRESSSERVICE = _descriptor.ServiceDescriptor(
  name='AddressService',
  full_name='yandex.cloud.vpc.v1.AddressService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2208,
  serialized_end=3431,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.vpc.v1.AddressService.Get',
    index=0,
    containing_service=None,
    input_type=_GETADDRESSREQUEST,
    output_type=yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2._ADDRESS,
    serialized_options=b'\202\323\344\223\002 \022\036/vpc/v1/addresses/{address_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetByValue',
    full_name='yandex.cloud.vpc.v1.AddressService.GetByValue',
    index=1,
    containing_service=None,
    input_type=_GETADDRESSBYVALUEREQUEST,
    output_type=yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2._ADDRESS,
    serialized_options=b'\202\323\344\223\002\033\022\031/vpc/v1/addresses:byValue',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.vpc.v1.AddressService.List',
    index=2,
    containing_service=None,
    input_type=_LISTADDRESSESREQUEST,
    output_type=_LISTADDRESSESRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/vpc/v1/addresses',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.vpc.v1.AddressService.Create',
    index=3,
    containing_service=None,
    input_type=_CREATEADDRESSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/vpc/v1/addresses:\001*\262\322* \n\025CreateAddressMetadata\022\007Address',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.vpc.v1.AddressService.Update',
    index=4,
    containing_service=None,
    input_type=_UPDATEADDRESSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002#2\036/vpc/v1/addresses/{address_id}:\001*\262\322* \n\025UpdateAddressMetadata\022\007Address',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.vpc.v1.AddressService.Delete',
    index=5,
    containing_service=None,
    input_type=_DELETEADDRESSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 *\036/vpc/v1/addresses/{address_id}\262\322*.\n\025DeleteAddressMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.vpc.v1.AddressService.ListOperations',
    index=6,
    containing_service=None,
    input_type=_LISTADDRESSOPERATIONSREQUEST,
    output_type=_LISTADDRESSOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/vpc/v1/addresses/{address_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.vpc.v1.AddressService.Move',
    index=7,
    containing_service=None,
    input_type=_MOVEADDRESSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(\"#/vpc/v1/addresses/{address_id}:move:\001*\262\322*\036\n\023MoveAddressMetadata\022\007Address',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADDRESSSERVICE)

DESCRIPTOR.services_by_name['AddressService'] = _ADDRESSSERVICE

# @@protoc_insertion_point(module_scope)
